;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Loading this file installs CG/JS.
;; Please see readme.txt for more information
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(in-package :user)

(eval-when (compile eval load)
  (require :shell)
  (use-package :excl.shell))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; validate files

(let ((platform-file
       (directory
	(merge-pathnames
	 "PLATFORM-*"
	 (path-pathname *load-pathname*)))))
  (or platform-file
      (error "Could not find the PLATFORM file."))
  
  (when (> (length platform-file) 1)
    (error "There is more than one PLATFORM file: ~a." platform-file))
  (setq platform-file (car platform-file))
  
  (or (=~ "^PLATFORM-(.*)" (file-namestring platform-file))
      (error "Cannot parse the PLATFORM file."))
  
  (let ((expected-platform $1)
	(current-platform
	 (format nil "~a~a" (symbol-name sys::.os.) #+smp "smp" #-smp "")))
    (or (string-equal expected-platform current-platform)
	(error
	 "The current platform (~a) does not match the downloaded version (~a)."
	 current-platform expected-platform)))
  ;; We are on the correct platform, fall through...
  )

;; HTML files needed for the operation of CG/JS
;; (this variable's value is generated by build_cgjs.sh)
(defvar *html-files* '("cgjs.html" "ssl-not-found.html" "browser-not-supported.html" ))

(defvar *extra-files*)
(setq *extra-files* nil)

(dolist (file *html-files*)
  (setq file (merge-pathnames file *load-pathname*))
  (or (probe-file file)
      (error "~a does not exist." file))
  (push file *extra-files*))
;; All *html-files* exist...

;; These two are directories but the pathname is specified as
;; a file, so merging works below.
(defvar *cg2js-directory* (merge-pathnames "code.cg2js" *load-pathname*))
(defvar *idejs-directory* (merge-pathnames "code.idejs" *load-pathname*))

(dolist (d (list *cg2js-directory* *idejs-directory*))
  (or (probe-file d)
      (error "~a does not exist." d)))

;; MD5 checksums of the incoming files
;; (this variable's value is generated by build_cgjs.sh)
(defvar *checksums* 
'(
(#x85ba066a070cd3928a0ae1b4926a11e8 . "./code.cg2js/cg-cursor-pixmap.fasl")
(#xf45f9ab3bc390d83855f11ed61d584fd . "./code.cg2js/cg-printing.fasl")
(#xbb559c34ad15afa7e710b0293679ccde . "./code.cg2js/cg-caret.fasl")
(#x3d9bf0ee591f907d20698ea7fbc7b0a4 . "./code.cg2js/cg-item-list.fasl")
(#x8b0bb87ae24406d19de56e5028dd5ea5 . "./code.cg2js/cg-progress-indicator.fasl")
(#x24146cc1ddbf667958d40834682d7b77 . "./code.cg2js/cg-outline-edit-in-place.fasl")
(#x2dfb6ab9d11e7abdcee7febab41b4531 . "./code.cg2js/cg-outline.fasl")
(#xfbc4c583b6c1a3302ae7ae4dec47b7a3 . "./code.cg2js/cg-palette.fasl")
(#xbf2036b219a1794ef53bd448206acb14 . "./code.cg2js/cg-selected-object.fasl")
(#x986c8f1b116ee4535b4786efb61fb779 . "./code.cg2js/cg-status-bar.fasl")
(#x058a4d31ab3324d47ac3b8a77155d88d . "./code.cg2js/cg-wrap-string.fasl")
(#xb59a497ef7ea714e1ad22a1d05e87a89 . "./code.cg2js/cg-fill-texture.fasl")
(#x98852dfbefb175bcfa3ea49740f9cc55 . "./code.cg2js/cg-layout.fasl")
(#x7a2b52aa00722c407ebcd9970b89e419 . "./code.cg2js/cg-timer.fasl")
(#x8e4b0ea1ef75c34fd722b578934d6b0c . "./code.cg2js/cg-dialog-item.fasl")
(#xc78f7be3022daf5dc32e023c5c739fea . "./code.cg2js/cg-button.fasl")
(#x55079455d357f1def89490939e950b69 . "./code.cg2js/cg-grid-widget-drag-and-drop.fasl")
(#xc748dff495111e9e82b37c902bd7fc49 . "./code.cg2js/cg-tray.fasl")
(#xb8892cc9d43e7dda3f03bac35d0b686e . "./code.cg2js/cg-plot-widget.fasl")
(#xd3438d4118b17a202d0f40c8da4696f2 . "./code.cg2js/cg-pixmap.fasl")
(#x0c0161eaca63e50ea7407a5c73976389 . "./code.cg2js/cg-font-dialog.fasl")
(#x143cab0da0560d8be355338d0d46ab85 . "./code.cg2js/cg-os-widget.fasl")
(#x5cf6a1c1a76e1ffee94dce5d9ed21720 . "./code.cg2js/cg-text-or-combo.fasl")
(#xbd6c036a9638b0e6500f7b7095ecfd14 . "./code.cg2js/cg-trackbar.fasl")
(#x819fe7dc061c239a22ec418ffc33e672 . "./code.cg2js/cg-up-down-control.fasl")
(#x88914e8d4723b7ceba3066443929f9f3 . "./code.cg2js/cg-text-edit-pane-file-io.fasl")
(#x2c1f40959888e50cd5be32b04be68ed9 . "./code.cg2js/cg-outline-drag-and-drop.fasl")
(#x107aed5f99cdbe6235764804d837564f . "./code.cg2js/cg-intersect-posbox.fasl")
(#xc095226ffbd80ffe64e85e36f260e27a . "./code.cg2js/cg-bitmap-stream.fasl")
(#xc5b548b2c5a518cf61cf7ca97a489d4e . "./code.cg2js/cg-chart-widget.fasl")
(#xa6900c934c4809471d24bf831548dfe4 . "./code.cg2js/cg-multi-line-editable-text.fasl")
(#x710f69670607f81c311475da7ef1601f . "./code.cg2js/cg-group-box.fasl")
(#x9669f734be8ac51b038bdf295dd84553 . "./code.cg2js/cg-static-text.fasl")
(#x27e13dc6bab99e71f6bc7e495713260b . "./code.cg2js/cg-class-slot-grid.fasl")
(#xfb4fd1d87ddbba2da0b9528976158594 . "./code.cg2js/cg-color-dialog.fasl")
(#xf9a351ef8c61c4b187424a811862c21c . "./code.cg2js/cg-intersect.fasl")
(#x22b412d86451266a47ac3c98dea861a1 . "./code.cg2js/cg-gesture-emulation.fasl")
(#xc3fc8f40645283574e9e56f54b64c69a . "./code.cg2js/cg-drawable-clipboard.fasl")
(#x4b481f6a1d4d1cdd9700f9739db3b096 . "./code.cg2js/cg-html-dialog.fasl")
(#xe295232778bf0ee06132058f922c2078 . "./code.cg2js/cg-lettered-menu.fasl")
(#x035bbf5190567c9cce0bf494616547c7 . "./code.cg2js/cg-class-grid.fasl")
(#xccd67ddf971223c196a791cec10752b9 . "./code.cg2js/cg-pixmap-printing.fasl")
(#xd24bc3219ec23e80d8b353ff25b8924b . "./code.cg2js/cg-calendar.fasl")
(#x1e5787dd977cfcc5b263acf2f524d18c . "./code.cg2js/cg-editable-text.fasl")
(#x296c58c4ab28a71b753ccf76a328145e . "./code.cg2js/cg-property.fasl")
(#xb6ea3ad37fd4859aca3a5bb2a01245f9 . "./code.cg2js/cg-drag-and-drop-image.fasl")
(#x824cf09086d39a17dee689b562340a73 . "./code.cg2js/cg-grid-widget.fasl")
(#x6076da656dbec3e4da8c5a19fe38355f . "./code.cg2js/cg-paren-matching.fasl")
(#x49928757d012d5e4b1190ebf63c13137 . "./code.cg2js/cg-dev.fasl")
(#x7d76ad2c6bda37e50c5d4fee5241f8d4 . "./code.cg2js/cg-drawable.fasl")
(#x935603c7b3075c0c878d4ac11cb0a5fe . "./code.cg2js/cg-curve.fasl")
(#x8b3e11668d77bf948fe3699592e344de . "./code.cg2js/cg-lisp-widget.fasl")
(#x3d117489ce13aec5a621390582af2ef5 . "./code.cg2js/cg-dde-utils.fasl")
(#x03ca673af9e2baafce6910fd75a34c72 . "./code.cg2js/cg-pixmap-file-io.fasl")
(#xa17e4657ddb29e62b51304881e3875f0 . "./code.cg2js/cg-object-editor-layout.fasl")
(#xbb5b745a06b9b4ee6b96a72fbc605f8c . "./code.cg2js/cg-multi-picture-button-tooltip.fasl")
(#xeda6230e432de38c3ed7a0fa98d4d842 . "./code.cg2js/cg-multi-line-lisp-text.fasl")
(#xaa096d61833b868169c1f70d6957fc09 . "./code.cg2js/cg-lamp.fasl")
(#x98eba2b602a17c9d7afc37ee55e98cf1 . "./code.cg2js/cg-common-control.fasl")
(#x22e29b9d37f40ee5c6ddf2e53260c9e2 . "./code.cg2js/cg-picture-widget-palette.fasl")
(#xc098879e5691b75b313d9412062f4302 . "./code.cg2js/cg-directory-dialog-os.fasl")
(#xacab675067d957c5043bd214be77b4c0 . "./code.cg2js/cg-bitmap-pane-clipboard.fasl")
(#x6da1cedecd360a7c15f25e6af174a7ee . "./code.cg2js/cg-project-window.fasl")
(#xf82ed21383167e641f220f1ca0133182 . "./code.cg2js/cg-sample-file-menu.fasl")
(#xf5b84d75a339de6a272cb20a9ee1736b . "./code.cg2js/cg-class-support.fasl")
(#x71cc688bdbfe051a0ff8f103d8fd5842 . "./code.cg2js/cg-multi-picture-button.fasl")
(#x7bd4e102d53746c4a13781c109c5a147 . "./code.cg2js/cg-yes-no-list.fasl")
(#x60b2d2baf66160055235c48367f73865 . "./code.cg2js/cg-scrolling-static-text.fasl")
(#x75b57507bb851d7df69941acebd15ceb . "./code.cg2js/cg-string-dialog.fasl")
(#xb6b9f7aadc7c9a2202a08d58c91b428c . "./code.cg2js/cg-menu-tooltip.fasl")
(#xc1094a0c7b9dd48f8bd785973881d3e2 . "./code.cg2js/cg-dropping-outline.fasl")
(#xf12618b528a0c81091db358d870dbc27 . "./code.cg2js/cg.fasl")
(#x96493a6951d1a76fcb9bb948ffcd0c11 . "./code.cg2js/cg-text-edit-pane-mark.fasl")
(#xd454ab43b71f2588199c3ffb4f59ebf8 . "./code.cg2js/cg-scaling-stream.fasl")
(#x65ba862fc55de5e2e6eef1cf6dfc5a54 . "./code.cg2js/cg-yes-no-string.fasl")
(#x45eb1d7add1dabc8ba24f8b1a5e07c23 . "./code.cg2js/cg-icon-pixmap.fasl")
(#x48fda0dd788c8e392dabf14f3aff1680 . "./code.cg2js/cg-web-browser.fasl")
(#xcc86bd34007b82d06e6695fa3e92021b . "./code.cg2js/cg-clipboard-stack.fasl")
(#x6d581de8b313b449c3294b26bc185b5d . "./code.cg2js/cg-drag-and-drop.fasl")
(#x80e5d37a2bdda78f3bf933f0db040ef3 . "./code.cg2js/cg-message-dialog.fasl")
(#x8ab986e88cc5a874e434f50265ade716 . "./code.cg2js/cg-comtab.fasl")
(#xb5cafe000e07d77513e7dd5319e1f979 . "./code.cg2js/cg-base.fasl")
(#xce5c7e406e9c2c42314677ba4f7fef3d . "./code.cg2js/cg-pixmap-widget.fasl")
(#xe0ec535aae7b77ac0e9b4f32f8e742cd . "./code.cg2js/cg-rich-edit-pane.fasl")
(#xce4429496655722de44f570dd80263a9 . "./code.cg2js/cg-text-edit-pane.fasl")
(#x258276fe025d40f9b11225b5f31e43eb . "./code.cg2js/cg-utility-dialog.fasl")
(#xd0a60f6d5ff65c28e0bea9daf19b9089 . "./code.cg2js/cg-object-editor.fasl")
(#x0e96dd8b0269b0714c6c1d0f9cfc003e . "./code.cg2js/cg-edit-in-place.fasl")
(#xccb86683f16fbd709e4e32ed9875fc97 . "./code.cg2js/cg-radio-button.fasl")
(#x84d425d961b9d1a02dce797a048c9360 . "./code.cg2js/cg-clipboard-pixmap.fasl")
(#xc138af31ce66c2bc810e9db68ad9403b . "./code.cg2js/cg-nodes.fasl")
(#xc66ceb0c2e7118b16408f51a735fe9a3 . "./code.cg2js/cg-get-position.fasl")
(#x98559701ec40742f6064ddce16754d01 . "./code.cg2js/cg-directory-dialog.fasl")
(#x81acead4b4b717c1943cd1287b19f97d . "./code.cg2js/cg-lisp-text.fasl")
(#xb26988e67fda7a0b85528c1d71c5b77e . "./code.cg2js/cg-combo-box.fasl")
(#xb6387133218f09137fba35081fbeb77d . "./code.cg2js/cg-text-widget.fasl")
(#xdb9a0c9902f67172d2f46a8a2bc572cc . "./code.cg2js/cg-list-view.fasl")
(#xd575df61fe4ce2fbd59e4e88109e4a45 . "./code.cg2js/cg-header-control.fasl")
(#xdaadd712bbd30c5f5f486ed4685c2638 . "./code.cg2js/cg-graphics-context.fasl")
(#x009aefcaa3645135c8ba5fb1a2f509a3 . "./code.cg2js/cg-get-pixmap.fasl")
(#x4cc69e66ba6c10b0cc91707c20a113c4 . "./code.cg2js/cg-menu.fasl")
(#x2a3237c7b67d28afdc2cdfb9d044d084 . "./code.cg2js/cg-scroll-bar-mixin.fasl")
(#x61b827d22ae30da4584ebc3ff581fb3d . "./code.cg2js/cg-pixmap-rotate.fasl")
(#x4b9c02e442f69bc9c9ef5485f4d9ec96 . "./code.cg2js/cg-tooltip.fasl")
(#x584100b5a6cb16024dfa53574f17e864 . "./code.cg2js/cg-html-widget.fasl")
(#x6df2a80326d4b81a8c964e85afd68a47 . "./code.cg2js/cg-choice-list.fasl")
(#x8903e9621de09fb2f37268a0ca220cf2 . "./code.cg2js/cg-rich-edit-pane-printing.fasl")
(#xd678557a5123747023f58e63b636ac48 . "./code.cg2js/cg-rich-edit-pane-clipboard.fasl")
(#x875a4513ab4114ce7e3ac366ff4c9ef0 . "./code.cg2js/cg-icon.fasl")
(#xc27fb8081c2eb5237abafa12e877aea8 . "./code.cg2js/cg-acache.fasl")
(#x90e9c615b59d6621d1c3837b55195822 . "./code.cg2js/cg-template-string.fasl")
(#xf9695c8d7ccc1a10c962e617b2c75e30 . "./code.cg2js/cg-bitmap-pane.fasl")
(#x181f47ee30d7235cee7549e6c5d5b391 . "./code.cg2js/cg-toggling-widget.fasl")
(#xf7a6426570550d6e2fad77980cbf9375 . "./code.cg2js/cg-tab-control.fasl")
(#xc729da68497823dcd5920a1249234270 . "./code.cg2js/cg-split-bar.fasl")
(#xec227d93e4a995b7eb14c578e99790d2 . "./code.cg2js/cg-picture-widget.fasl")
(#x2e7240d4a76ab4eccfa64c84fe285718 . "./code.cg2js/cg-keyboard-shortcuts.fasl")
(#xa8e76ccd4e3a4a47940d2727dc5f40b5 . "./code.cg2js/cg-choose-printer.fasl")
(#xd3d0fb809f376add801b3f7cd00fd57a . "./code.cg2js/cg-os-window.fasl")
(#xeb4a0bcb0099626a21cfc2f02ba49557 . "./code.cg2js/cg-scroll-bar.fasl")
(#x96e7af8bab07c30fc4fb7a024225ed05 . "./code.cg2js/cg-clipboard.fasl")
(#x4f69f63403e5d198eb19749858ef5d4b . "./code.cg2js/cg-find-string-dialog.fasl")
(#x67909805c5db22e74cff02f9eda68484 . "./code.cg2js/cg-hotspot.fasl")
(#xe63c5aa4280c8e9564226a5d2199908f . "./code.cg2js/cg-rich-edit.fasl")
(#xb3d97559c2f5365c3b5491707dcc3324 . "./code.cg2js/cg-check-box.fasl")
(#xc6df14ac3ca461f3c3bee22b0109b860 . "./code.cg2js/cg-lisp-edit-pane.fasl")
(#xdb7ec8c292bd6015ee4eead490d19411 . "./code.cg2js/cg-file-dialog.fasl")
(#xf3961b4d279e7987df0280e5441f2a95 . "./code.cg2js/cg-toolbar.fasl")
(#x9c67237915fed33b23ec502cda90178c . "./code.cg2js/cg-multi-picture-button-drag-and-drop.fasl")
(#x0801bf46f2ce42dd6c92bbf7bcb7a6f3 . "./code.cg2js/cg-chart-or-plot.fasl")
(#xbc40ce9eb023c851bcd86366087dbfe5 . "./code.cg2js/cg-shortcut-menu.fasl")
(#xcc37a84740e65a08aafa0fe3fb6eaae5 . "./code.idejs/ide-project.fasl")
(#x84ef7ffa100658c11fce922f1673f742 . "./code.idejs/ide-intro.fasl")
(#x7b31394b7c4385b81dd82ffee2257da8 . "./code.idejs/ide-find-in-files.fasl")
(#xfaab3bbe6ffc6b48fbe2ef42a33c05ce . "./code.idejs/ide-grapher.fasl")
(#xaf2ed461a74040d8e195de91fdad768d . "./code.idejs/ide-inspector.fasl")
(#x9070325c691d3a427e5fa26c555cfb29 . "./code.idejs/ide-editor.fasl")
(#xce7d0840c1fd3c9a3c0107b3d80a233e . "./code.idejs/ide-window-list.fasl")
(#x26dce10357fd4d1aa83328a2495263c3 . "./code.idejs/ide-process-browser.fasl")
(#x7fc2b4bee87dd34f7781645a08771d7d . "./code.idejs/ide-patch-dialog.fasl")
(#x7de27c591126e1a767b7d8cffa2dd56b . "./code.idejs/ide-class-grapher.fasl")
(#x5f9f21f7f5135ac4deeac62e3f2fe993 . "./code.idejs/ide-base.fasl")
(#xca0974dbad499a29c00299632b1906a1 . "./code.idejs/ide.fasl")
(#x38bb4f1a8a406fd40b22dd24321bb09c . "./code.idejs/ide-trace.fasl")
(#x0a5982f48d1ac116466225809016216e . "./code.idejs/ide-form.fasl")
(#x8ca7c0eccef3728fd31b123c3f3bd158 . "./code.idejs/ide-find-definitions.fasl")
(#x862d00826d52ab999192085327c5de4f . "./code.idejs/ide-apropos.fasl")
(#xbeb8e15f392b848dafa5b1a3673f5459 . "./code.idejs/ide-class-browser.fasl")
(#xc7cf4091de801909a366af0a4193b2b1 . "./code.idejs/ide-navigator.fasl")
(#xd5a9c5917457d1eb59e7594e4c9f51fb . "./code.idejs/ide-clipboard.fasl")
(#xd801bc9ae9670449a9a7cbc587517712 . "./code.idejs/ide-acache.fasl")
(#x324531e1a18cc77a963b07701f36bed7 . "./code.idejs/ide-keyshort.fasl")
(#xb3d7177c71af2abad4760ccbf7f8502c . "./code.idejs/ide-package-list.fasl")
(#x72fe26e19d904ea6a37c10afe707331d . "./code.idejs/ide-dev.fasl")
(#xeb5b70ef6a4ced03becd92b82d3b0061 . "./cgjs.html")
(#x34779e5d4bbb71d45bf63f88fac54100 . "./ssl-not-found.html")
(#x90c6d2a65504d45266ad9fa3a49be2f9 . "./browser-not-supported.html"))
 )

(let ((files-ok
       (dolist (checksum *checksums* t)
	 (when (/= (car checksum)
		   (md5-file
		    (merge-pathnames (cdr checksum) *load-pathname*)))
	   (return nil)))))
  (cond
   ((not files-ok)
    (error "The extracted files failed the checksum test.  ~
Please download and/or extract again."))
   (t
    (format t "Checksums on files are OK...~%"))))

;; We have validated all the files are there...

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; check for needed patches

(eval-when (compile eval load) (require :build))

(defvar *required-patches* '(#+macosx ("build" . 3)))

(dolist (required-patch *required-patches*)
  (let ((existing-patch (assoc (car required-patch)
			    (cdr (assoc :system sys::*patches*))
			    :test #'string=)))
    (when (null existing-patch)
      (error "Could not find patch info for the ~s module."
	     (car required-patch)))
    (when (not (>= (second existing-patch) (cdr required-patch)))
      ;; The build patch number is NOT >= to the one we require
      (error "~
Expected version ~d of ~s but have version ~d.  Please update ~
your lisp with update.~a and then do the CG/JS installation again."
	     (cdr required-patch) (car required-patch)
	     (second existing-patch)
	     #+mswindows "exe"
	     #-mswindows "sh"))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; copy files

(defun copy (source dest)
  (cond
   ((file-directory-p source)
    (format t "Copy directory ~a~%" (enough-namestring source))
    (copy-directory source dest :quiet t))
   (t
    (format t "Copy file ~a~%" (enough-namestring source))
    (sys:copy-file source dest :verbose nil))))

(defvar *sys* (translate-logical-pathname (pathname "sys:")))

(cond
 ((excl::pathname-equalp (truename *sys*)
			 (path-pathname *load-truename*))
  (format t "Files are already in place, no copying requiring.~%"))
 (t ;; copy files, replacing them with new ones if they already exist
  (let (dest)
    (dolist (from *extra-files*)
      (setq dest (merge-pathnames (file-namestring from) *sys*))
      (when (probe-file dest) (delete-file dest))
      (copy from dest))
    
    (dolist (from (list *cg2js-directory* *idejs-directory*))
      (setq dest (merge-pathnames (file-namestring from) *sys*))
      ;; now make it a directory pathname
      (setq dest (pathname-as-directory dest))

      (when (probe-file dest) (delete-directory-and-files dest))
      (copy (pathname-as-directory from) dest)))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; update develenv.cl to load CG/JS before the original version of CG

(defvar *setup-cgjs-loading* "sys:setup-cgjs-loading.cl")

;; Because users might use an ANSI lisp to install, have to make sure
;; the resulting file can be loaded into an ANSI and Modern lisp.
(with-open-file (s *setup-cgjs-loading* :direction :output
		 :if-exists :supersede)
  (format s "~
;; This file was created by install-cgjs.cl.
;; Please do not edit it.

")
  (dolist (dir (list "code.cg2js/" "code.idejs/"))
    (format s "
(let ((path (make-pathname
	     :type \"fasl\"
	     :directory (pathname-directory
			 (merge-pathnames
			  ~s
			  (translate-logical-pathname \"sys:\"))))))
  (format t \";; *require-search-list*: adding: ~~s~%\" path)
  (push path sys:*require-search-list*))

"
	    dir)))

(defvar *develenv.cl* (pathname "sys:develenv.cl"))

(when (not (probe-file *develenv.cl*))
  (setf (file-contents *develenv.cl*)
    ";; This file is loaded before images are rebuilt with update.sh/update.exe

"))

(let ((contents (file-contents *develenv.cl*)))
  (cond
   ((match-re
     (format nil "^#\\|\\|# \\(load \"sys:~a"
	     (file-namestring *setup-cgjs-loading*))
     contents
     :multiple-lines t)
    (format t "develenv.cl already correctly loads CG/JS.~%"))
   ((match-re
     (format nil "^#\\+ignore \\(load \"sys:~a"
	     (file-namestring *setup-cgjs-loading*))
     contents
     :multiple-lines t)
    (format t "develenv.cl: CG/JS disabled; will enable.~%")
    (setf (file-contents *develenv.cl*)
      (replace-re  contents
		  (format nil "^#\\+ignore *\\(load \"sys:~a"
			  (file-namestring *setup-cgjs-loading*))
		  (format nil "#||# (load \"sys:~a"
			  (file-namestring *setup-cgjs-loading*))
		  :multiple-lines t
		  :count 1)))
   (t
    (format t "develenv.cl: adding CG/JS initialization.~%")
    (setf (file-contents *develenv.cl*)
      (concatenate 'simple-string
	contents
	(format nil "~

;; To disable the use of CG/JS and go back to the originally released
;; (and possibly patched) version of CG/IDE, change the #||# to
;; #+ignore on the following line and the rebuild images by running
;; update.sh or update.exe, depending on your platform:
#||# (load \"sys:~a\")~%~%"
		(file-namestring *setup-cgjs-loading*)))))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; success!

(let ((msg (format nil "~
CG/JS installation successful!

NOTE: to use CG/JS you must rebuild images by running 'update.~a'
      in the Allegro CL directory (~a)."
		   #+mswindows "exe"
		   #-mswindows "sh"
		   *sys*)))
  #-mswindows (format t "~&~%~a~%" msg)
  #+mswindows (excl::internal-message-box msg "CG/JS Installation" :type :ok))
